/*
 * The contents of this file are
 * published under the Mozilla Public License 1.1
 */
__IMPORT__
	(
	'chrome://mozlib/content/lib/js/asrdf/',
	'base_parser.js',
	'property_parser.js',
	'outline_parser.js',
	'triple_parser.js'
	);


//@@@@@@@@@@@@@@@@
function ASRDF_Parser		//<c><e>ASRDF_BaseParser<a>public<d>Source line parser class
(){
//================
this.ASRDF_Parser = function		//<m>void<a>private<d>class constructor
(){
this.className	= 'ASRDF_Parser';
//i12n
this.state			= this.K.SECTION.START;
this.doctypeParser	= new ASRDF_PropertyParser();
this.namespaceParser= new ASRDF_PropertyParser();
this.propertyParser	= new ASRDF_PropertyParser();
this.tripleParser	= new ASRDF_TripleParser(this.propertyParser);
}//</m>ASRDF_Parser



//================
this.setIn = function		//<m>int<a>protected<d>Parse a source line
(
line		//<p>string<d>Source line
){
var
processCode = this.K.ERROR.NONE;
if(this.testCodeLine(line)){
	var
	/*string*/method,
	/*string[]*/code = line.split(this.K.COMMENT.DELIMITER)[0],
	/*int*/state = this.getState(code);
	if(state) this.state = state;
	else{
		switch(this.state){
			case this.K.SECTION.START:
				break;
			case this.K.SECTION.IMPORT_DOCTYPE:
				method = 'setImportDoctype';
				break;
			case this.K.SECTION.DOCTYPE:
				method = 'setDoctype';
				break;
			case this.K.SECTION.IMPORT_NS:
				method = 'setImportNamespaces';
				break;
			case this.K.SECTION.NS:
				method = 'setNamespaces';
				break;
			case this.K.SECTION.IMPORT_KEYS:
				method = 'setImportKeys';
				break;
			case this.K.SECTION.KEYS:
				method = 'setKeys';
				break;
			case this.K.SECTION.IMPORT_TRIPLES:
				method = 'setImportTriples';
				break;
			case this.K.SECTION.TRIPLES:
				method = 'setTriples';
				break;
			default:
				return this.K.ERROR.NO_SUCCESS;
			}	//---switch
		}
	if(method) processCode = this[method](code);
	}
return processCode;
}//</m>setIn



//================
this.setImportDoctype = function		//<m>void<a>private<d>Set up import property file
(
path		//<p>string<d>Property file path
){
new ASRDF_FileReader(path, this.doctypeParser);
}//</m>setImportDoctype



//================
this.setDoctype = function		//<m>void<a>private<d>Set up DOCTYPE declaration
(
entity		//<p>string<d>Entity and value
){
this.doctypeParser.setIn(entity);
}//</m>setDoctype



//================
this.setImportNamespaces = function		//<m>void<a>private<d>Set up import property file
(
path		//<p>string<d>Property file path
){
new ASRDF_FileReader(path, this.namespaceParser);
}//</m>setImportNamespaces



//================
this.setNamespaces = function		//<m>void<a>private<d>Set up namespace URI
(
keyValue		//<p>string<d>Namespace prefix and value
){
this.namespaceParser.setIn(keyValue);
}//</m>setNamespaces



//================
this.setImportKeys = function		//<m>void<a>private<d>Set up import property file
(
path		//<p>string<d>Property file path
){
new ASRDF_FileReader(path, this.propertyParser);
}//</m>setImportKeys



//================
this.setKeys = function		//<m>void<a>private<d>Set up property key
(
keyValue		//<p>string<d>Property key and value
){
this.propertyParser.setIn(keyValue);
}//</m>setKeys



//================
this.setImportTriples = function		//<m>void<a>private<d>Set up triple file
(
path		//<p>string<d>Property file path
){
new ASRDF_FileReader(path, this);
}//</m>setImportTriples



//================
this.setTriples = function		//<m>int<a>private<d>Set up triple component
(
code		//<p>string<d>Triple component value
){
return this.tripleParser.setIn(code);
}//</m>setTriples



//================
this.getState = function		//<m>int<d>Get parsing state
(
code		//<p>string<d>Line value
){
return this.testImportDoctypeLine(code) ? this.K.SECTION.IMPORT_DOCTYPE :
	this.testDoctypeLine(code) ? this.K.SECTION.DOCTYPE :
		this.testImportNsLine(code) ? this.K.SECTION.IMPORT_NS :
			this.testNsLine(code) ? this.K.SECTION.NS :
				this.testImportKeysLine(code) ? this.K.SECTION.IMPORT_KEYS :
					this.testKeysLine(code) ? this.K.SECTION.KEYS :
							this.testImportTriplesLine(code) ? this.K.SECTION.IMPORT_TRIPLES :
								this.testTriplesLine(code) ? this.K.SECTION.TRIPLES :
								null;
}//</m>getState



//================
this.getDoctypeSet = function		//<m>string<a>protected<d>Get doctypeSet
(){
return this.doctypeParser.get_propertySet();
}//</m>getDoctypeSet



//================
this.getNamespaceSet = function		//<m>string<a>protected<d>Get namespaceSet
(){
return this.namespaceParser.get_propertySet();
}//</m>getNamespaceSet



//================
this.getPropertySet = function		//<m>string<a>protected<d>Get namespaceSet
(){
return this.propertyParser.get_propertySet();
}//</m>getPropertySet



//================
this.getTripleSet = function		//<m>string<a>protected<d>Get tripleSet
(){
return this.tripleParser.get_tripleSet();
}//</m>getTripleSet



//================
this.testImportDoctypeLine = function		//<m>boolean<a>private<d>Check whether line is a doctype declaration line
(
line		//<p>string<d>Source line
){
return line.match(this.K.DECLARE.IMPORT_DOCTYPE);
}//</m>testImportDoctypeLine



//================
this.testDoctypeLine = function		//<m>boolean<a>private<d>Check whether line is a doctype declaration line
(
line		//<p>string<d>Source line
){
return line.match(this.K.DECLARE.DOCTYPE);
}//</m>testDoctypeLine



//================
this.testImportNsLine = function		//<m>boolean<a>private<d>Check whether line is an import namespaces declaration line
(
line		//<p>string<d>Source line
){
return line.match(this.K.DECLARE.IMPORT_NS);
}//</m>testImportNsLine



//================
this.testNsLine = function		//<m>boolean<a>private<d>Check whether line is a namespaces declaration line
(
line		//<p>string<d>Source line
){
return line.match(this.K.DECLARE.NS);
}//</m>testNsLine



//================
this.testImportKeysLine = function		//<m>boolean<a>private<d>Check whether line is an import keys declaration line
(
line		//<p>string<d>Source line
){
return line.match(this.K.DECLARE.IMPORT_KEYS);
}//</m>testImportKeysLine



//================
this.testKeysLine = function		//<m>boolean<a>private<d>Check whether line is a keys declaration line
(
line		//<p>string<d>Source line
){
return line.match(this.K.DECLARE.KEYS);
}//</m>testKeysLine



//================
this.testImportTriplesLine = function		//<m>boolean<a>private<d>Check whether line is an import triples declaration line
(
line		//<p>string<d>Source line
){
return line.match(this.K.DECLARE.IMPORT_TRIPLES);
}//</m>testImportTriplesLine



//================
this.testTriplesLine = function		//<m>boolean<a>private<d>Check whether line is a triples declaration line
(
line		//<p>string<d>Source line
){
return line.match(this.K.DECLARE.TRIPLES);
}//</m>testTriplesLine



this.K.SECTION =
	{
	START:			0,
	IMPORT_DOCTYPE:	1,
	DOCTYPE:		2,
	IMPORT_NS:		3,
	NS:				4,
	IMPORT_KEYS:	5,
	KEYS:			6,
	IMPORT_TRIPLES:	7,
	TRIPLES:		8,
	END:			-1
	};
this.K.DECLARE =
	{
	IMPORT_DOCTYPE:	/^\.import_doctype$/,
	DOCTYPE:		/^\.doctype$/,
	IMPORT_NS:		/^\.import_ns$/,
	NS:				/^\.ns$/,
	IMPORT_KEYS:	/^\.import_keys$/,
	KEYS:			/^\.keys$/,
	IMPORT_TRIPLES:	/^\.import_triples$/,
	TRIPLES:		/^\.triples$/
	};



this.ASRDF_Parser();
}//</c>ASRDF_Parser
ASRDF_Parser.prototype = new ASRDF_BaseParser;

